@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import os
+import ujson
 import random
 import itertools
 
@@ -8,75 +9,52 @@ main_dir = os.path.split(os.path.abspath(__file__))[0]
 
 
 class Random(dict):
+
     def __init__(self, file):
+        self.types_file = {
+            'nouns': self.load_nouns,
+            'nicknames': self.load_nicknames,
+            'dmails': self.load_dmails,
+        }
+
         self.load_file(file)
 
     def load_file(self, file):
-        """Opening file.
-
+        """
         :param str file: filename
         """
-        if file == 'nouns':
-            self.load_nouns(file)
-        elif file == 'nicknames':
-            self.load_nicknames(file)
-        elif file == 'dmails':
-            self.load_dmails(file)
+        self.types_file[file](file)
 
     def load_nouns(self, file):
-        """Making dict for words.
+        """
+        Load dict from file for random words.
 
         :param str file: filename
         """
-        with open(os.path.join(main_dir, file + '.txt'), 'r') as f:
-            for word in f:
-                word = word.strip()
-                letter = word[0]
-
-                try:
-                    self[letter].append(word)
-                except KeyError:
-                    self[letter] = [word]
+        with open(os.path.join(main_dir, file + '.dat'), 'r') as f:
+            self.nouns = ujson.load(f)
 
     def load_dmails(self, file):
-        """Making set for random mails
+        """
+        Load list from file for random mails
 
         :param str file: filename
         """
-        self['domains'] = set()
-
-        with open(os.path.join(main_dir, file + '.txt'), 'r') as f:
-            for domain in f:
-                domain = domain.strip()
-                self['domains'].add(domain)
-
-        self['domains'] = frozenset(self['domains'])
+        with open(os.path.join(main_dir, file + '.dat'), 'r') as f:
+            self['domains'] = frozenset(ujson.load(f))
 
     def load_nicknames(self, file):
-        """Making dict for words.
+        """
+        Load dict from file for random nicknames.
 
         :param str file: filename
         """
-        self['f'] = dict()
-        self['m'] = dict()
-        self['u'] = dict()
-
-        with open(os.path.join(main_dir, file + '.txt'), 'r') as f:
-            for word in f:
-                word = word.strip()
-                gender = word[0]
-                letter = word[1].lower()
-                nick = word[1:]
-
-                try:
-                    self[gender][letter].append(nick)
-                    self['u'][letter].append(nick)
-                except KeyError:
-                    self[gender][letter] = [nick]
-                    self['u'][letter] = [nick]
+        with open(os.path.join(main_dir, file + '.dat'), 'r') as f:
+            self.nicknames = ujson.load(f)
 
     def check_count(self, count):
-        """Checks count
+        """
+        Checks count
 
         :param int count: count number ;)
         :raises: ValueError
@@ -88,12 +66,14 @@ class Random(dict):
 
 
 class RandomWords(Random):
+
     def __init__(self):
         super(RandomWords, self).__init__('nouns')
         self.available_letters = 'qwertyuiopasdfghjklzcvbnm'
 
     def random_word(self, letter=None):
-        """Returns random word.
+        """
+        Return random word.
 
         :param str letter: letter
         :rtype: str
@@ -102,7 +82,8 @@ class RandomWords(Random):
         return self.random_words(letter)[0]
 
     def random_words(self, letter=None, count=1):
-        """Returns list of random words.
+        """
+        Returns list of random words.
 
         :param str letter: letter
         :param int count: how much words
@@ -113,7 +94,8 @@ class RandomWords(Random):
         self.check_count(count)
 
         if letter is None:
-            all_words = list(itertools.chain.from_iterable(self.values()))
+            all_words = list(
+                itertools.chain.from_iterable(self.nouns.values()))
 
             try:
                 words = random.sample(all_words, count)
@@ -126,13 +108,15 @@ class RandomWords(Random):
             raise ValueError('Param "letter" must be string.')
 
         elif letter not in self.available_letters:
-            raise ValueError('Param "letter" must be in {0}.'.format(self.available_letters))
+            raise ValueError(
+                'Param "letter" must be in {0}.'.format(
+                    self.available_letters))
 
         elif letter in self.available_letters:
             try:
-                words = random.sample(self[letter], count)
+                words = random.sample(self.nouns[letter], count)
             except ValueError:
-                len_sample = len(self[letter])
+                len_sample = len(self.nouns[letter])
                 raise ValueError('Param "count" must be less than {0}. \
 (It is only {0} words for letter "{1}")'.format(len_sample + 1, letter))
 
@@ -145,20 +129,25 @@ class RandomNicknames(Random):
         self.available_letters = 'qwertyuiopasdfghjklzxcvbnm'
 
     def random_nick(self, letter=None, gender=None):
-        """Returns random nick.
+        """
+        Return random nick.
 
         :param str letter: letter
-        :param str gender: 'f' for female, 'm' for male and None for both
+
+        :param str gender: ``'f'`` for female, ``'m'`` for male and None for\
+            both
+
         :rtype: str
         :returns: random nick
         """
         return self.random_nicks(letter, gender)[0]
 
     def random_nicks(self, letter=None, gender=None, count=1):
-        """Returns list of random nicks.
+        """
+        Return list of random nicks.
 
         :param str letter: letter
-        :param str gender: 'f' for female, 'm' for male and None for both
+        :param str gender: ``'f'`` for female, ``'m'`` for male and None for both
         :param int count: how much nicks
         :rtype: list
         :returns: list of random nicks
@@ -175,7 +164,8 @@ class RandomNicknames(Random):
             else:
                 g = gender
 
-            all_nicks = list(itertools.chain.from_iterable(self[g].values()))
+            all_nicks = list(
+                itertools.chain.from_iterable(self.nicknames[g].values()))
 
             try:
                 nicks = random.sample(all_nicks, count)
@@ -188,7 +178,9 @@ class RandomNicknames(Random):
             raise ValueError('Param "letter" must be string.')
 
         elif letter not in self.available_letters:
-            raise ValueError('Param "letter" must be in "{0}".'.format(self.available_letters))
+            raise ValueError(
+                'Param "letter" must be in "{0}".'.format(
+                    self.available_letters))
 
         elif letter in self.available_letters:
             if gender:
@@ -197,9 +189,9 @@ class RandomNicknames(Random):
                 g = 'u'
 
             try:
-                nicks = random.sample(self[g][letter], count)
+                nicks = random.sample(self.nicknames[g][letter], count)
             except ValueError:
-                len_sample = len(self[g][letter])
+                len_sample = len(self.nicknames[g][letter])
                 raise ValueError('Param "count" must be less than {0}. \
 (It is only {0} nicks for letter "{1}")'.format(len_sample + 1, letter))
 
@@ -212,19 +204,26 @@ class RandomEmails(Random):
         self.rn = RandomNicknames()
 
     def randomMail(self):
-        """Method returns random e-mail
+        """
+        Return random e-mail.
 
         :rtype: str
-        :returns: random e-mail"""
+        :returns: random e-mail
+        """
         return self.randomMails()[0]
 
     def randomMails(self, count=1):
-        """Method returns random e-mails
+        """
+        Return random e-mails.
 
         :rtype: list
-        :returns: list of random e-mails"""
+        :returns: list of random e-mails
+        """
         self.check_count(count)
         random_nicks = self.rn.random_nicks(count=count)
         random_domains = random.sample(self['domains'], count)
 
-        return [nick.lower() + "@" + domain for nick, domain in zip(random_nicks, random_domains)]
+        return [
+            nick.lower() + "@" + domain for nick, domain in zip(random_nicks,
+                                                                random_domains)
+        ]
